Learn R Programming

elliptic (version 0.4-13)

e16.28.1: Numerical verification of equations 16.28.1 to 16.28.5

Description

Verifies formulae 16.28.1 to 16.28.5 on p576

Usage

e16.28.1(z, m, ...)
e16.28.2(z, m, ...)
e16.28.3(z, m, ...)
e16.28.4(z, m, ...)
e16.28.5(m, ...)

Arguments

z
Complex number
m
Parameter $m$
...
Extra arguments passed to theta[1-4]()

Details

Returns the left hand side minus the right hand side of each formula. Each formula documented here is identically zero; nonzero values are returned due to numerical errors and should be small.

References

AMS-55

Examples

Run this code
plot(e16.28.4(z=1:6000,m=0.234))
 plot(abs(e16.28.4(z=1:6000,m=0.234+0.1i)))

Run the code above in your browser using DataLab