Learn R Programming

elliptic (version 0.4-13)

half.periods: Calculates half periods in terms of e

Description

Calculates half periods in terms of $e$

Usage

half.periods(ignore=NULL, e=NULL, g=NULL, primitive)

Arguments

e
e
g
g
ignore
Formal argument present to ensure that e or g is named (ignored)
primitive
Boolean, with default TRUE meaning to return primitive periods and FALSE to return the direct result of Legendre's iterative scheme.

Value

  • Returns a pair of primitive half periods

Details

Parameter e=c(e1,e2,e3) are the values of the Weierstrass P function at the periods: $$e_1=P(\omega_1)\qquad e_2=P(\omega_2)\qquad e_3= p(\omega_3)$$ where $\omega_1+\omega_2+\omega_3=0$. Also, $e$ is given by the roots of the cubic equation $x^3-g_2x-g_3=0$, but the problem is finding which root corresponds to which of the three elements of $e$.

References

AMS-55

Examples

Run this code
half.periods(g=c(8,4))                ## Example 6, p665, LHS

u <- half.periods(g=c(-10,2))
massage(c(u[1]-u[2] , u[1]+u[2]))     ## Example 6, p665, RHS

half.periods(g=c(10,2))               ## Example 7, p665, LHS

u <- half.periods(g=c(7,6))
massage(c(u[1],2*u[2]+u[1]))          ## Example 7, p665, RHS



half.periods(g=c(1,1i, 1.1+1.4i))
half.periods(e=c(1,1i, 2, 1.1+1.4i))

Run the code above in your browser using DataLab