Learn R Programming

elliptic (version 0.4-13)

lattice: Lattice of complex numbers

Description

Returns a lattice of numbers generated by a given complex basis.

Usage

lattice(p,n)

Arguments

p
Complex vector of length two giving a basis for the lattice
n
size of lattice

Examples

Run this code
lattice(c(1+10i,100+1000i),n=2)
plot(lattice(c(1+1i,1.1+1.4i),5))

Run the code above in your browser using DataLab