Learn R Programming

elliptic (version 1.2-2)

p1.tau: Does the right thing when calling g2.fun() and g3.fun()

Description

Takes vectors and interprets them appropriately for input to g2.fun() and g3.fun(). Not really intended for the end user.

Usage

p1.tau(b)

Arguments

b
Vector of periods

Value

  • Returns a two-component list:
  • p1First period
  • tauPeriod ratio

Details

If b is of length two, interpret the elements as $\omega_1$ and $\omega_2$ respectively.

If a two-column matrix, interpret the columns as $\omega_1$ and $\omega_2$ respectively.

Otherwise, interpret as a vector of $\tau=\omega_1/\omega_2$.

Examples

Run this code
p1.tau(c(1+1i,1.1+23.123i))

Run the code above in your browser using DataLab