Learn R Programming

elliptic (version 0.4-13)

theta1dash: Derivatives of theta functions

Description

First, second, and third derivatives of the theta functions

Usage

give.n = FALSE, 
theta1dash(z, ignore = NULL, m = NULL, q = NULL, give.n = FALSE, maxiter = 30)
theta1dashdash(z, ignore = NULL, m = NULL, q = NULL, give.n = FALSE, maxiter = 30)
theta1dashdashdash(z, ignore = NULL, m = NULL, q = NULL, give.n = FALSE, maxiter = 30)

Arguments

z
Primary complex argument
ignore
Dummy argument to force the user to name the next argument either m or q
m
m
q
q
give.n
Boolean with default FALSE meaning to return the function evaluation, and TRUE meaning to return a two element list, with first element the function evaluation, and second element the number of iterations used.
maxiter
Maximum number of iterations

Details

Uses direct expansion as for theta1() et seq

References

ams-55

See Also

theta

Examples

Run this code
m <- 0.3+0.31i
z <- seq(from=1,to=2+1i,len=7)
delta <- 0.001
deriv.numer <- (theta1dashdash(z=z+delta,m=m) - theta1dashdash(z=z,m=m))/delta
deriv.exact <- theta1dashdashdash(z=z+delta/2,m=m)
abs(deriv.numer-deriv.exact)

Run the code above in your browser using DataLab